==> zio-aws-iot1clickdevices_2.13-5.17.126.2-sources.jar: zio/aws/iot1clickdevices/model/ListTagsForResourceRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.ListTagsForResourceRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.ListTagsForResourceRequest
      .wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.ListTagsForResourceRequest =
      zio.aws.iot1clickdevices.model.ListTagsForResourceRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.ListTagsForResourceRequest
  ) extends zio.aws.iot1clickdevices.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.iot1clickdevices.model.primitives.__string(impl.resourceArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.ListTagsForResourceRequest
  ): zio.aws.iot1clickdevices.model.ListTagsForResourceRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot1clickdevices_2.13-6.20.78.2-sources.jar: zio/aws/iot1clickdevices/model/ListTagsForResourceRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.ListTagsForResourceRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.ListTagsForResourceRequest
      .wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.ListTagsForResourceRequest =
      zio.aws.iot1clickdevices.model.ListTagsForResourceRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.ListTagsForResourceRequest
  ) extends zio.aws.iot1clickdevices.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.ListTagsForResourceRequest
  ): zio.aws.iot1clickdevices.model.ListTagsForResourceRequest.ReadOnly =
    new Wrapper(impl)
}
